import request, { postBlob } from '@/utils/request'

export function workerElecConfirmList(data) {
  return request({
    url: `/worker/elec/confirm/list?moduleId=${data.moduleId}`,
    method: 'post',
    data
  })
}

export function workerElecConfirmListExport(data, name) {
  return postBlob({
    url: '/worker/elec/confirm/list/export',
    data,
    name
  })
}

export function workerElecConfirmDetail(params) {
  return request({
    url: '/worker/elec/confirm/detail',
    method: 'post',
    params
  })
}

export function workerElecConfirmCount(params) {
  return request({
    url: '/worker/elec/confirm/count',
    method: 'post',
    params
  })
}

// -------------------------------------

export function workerElecConfirmManualList(data) {
  return request({
    url: `/worker/elec/confirm/manual/list?moduleId=${data.moduleId}`,
    method: 'post',
    data
  })
}

export function workerElecConfirmManualDetail(params) {
  return request({
    url: '/worker/elec/confirm/manual/detail',
    method: 'post',
    params
  })
}

export function workerElecConfirmManualConfirm(params) {
  return request({
    url: '/worker/elec/confirm/manual/confirm',
    method: 'post',
    params
  })
}

export function workerElecConfirmManualCount(params) {
  return request({
    url: '/worker/elec/confirm/manual/count',
    method: 'post',
    params
  })
}

